/**********************************************************************
 *
 * gsdltools.h -- 
 * A component of the Greenstone digital library software
 * from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * Copyright (C) 1999  The New Zealand Digital Library Project
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *********************************************************************/


#ifndef GSDLTOOLS_H
#define GSDLTOOLS_H

// don't actually use this but some windows
// versions of STL complain about use of 
// bool keyword without it
#include "text_t.h"

// returns true if machine is little endian
bool littleEndian();


// escapes '\' and '_' characters with '\'
// note that single '\' characters occurring 
// naturally within text (or filenames!!) will
// be removed by the dm macro language
text_t dm_safe (const text_t &instring);


// gsdl_system spawns a completely separate program (i.e. the calling
// program continues and terminates normally). Arguments containing special
// characters (e.g. '&') should be quoted with ""
void gsdl_system (char *cmd, ostream &logout);


// gsdl_call_perl executes the perl script perl_cmd, passing it all the 
// arguments provided. 

// Arguments should be text_t's, the last argument should be an empty text_t.

// perl_cmd shouldn't contain the path to the script as we use "perl -S"
// to find it. This means that the PATH environment variable of the calling
// process should contain the directory where the perl_cmd script lives.

// Uses a standard system() call on unix and a synchronous _spawn() on windows.
// We use the _spawn() because windows 9* doesn't seem to pass the 
// environment of the calling process to the new process when using
// system (which we need to do).

// all arguments will be quoted with double quotes [""] so they should be unquoted
// when passed in.

// returns the exit status of the called process (-1 if system() or _spawn() failed)
int gsdl_call_perl (char *perl_cmd, ...);

// attempts to work out if perl is functional
bool perl_ok ();

#endif
